MeshFailure

Struct MeshFailure 

pub struct MeshFailure {
    pub actor_mesh_name: Option<String>,
    pub rank: Option<usize>,
    pub event: ActorSupervisionEvent,
}
Message about a supervision failure on a mesh of actors instead of a single actor.

Fields

actor_mesh_name: Option<String>

Name of the mesh which the event originated from.

rank: Option<usize>

Rank of the mesh from which the event originated. TODO: Point instead?

event: ActorSupervisionEvent

The supervision event on an actor located at mesh + rank.

Implementations

Source

impl MeshFailure

pub fn default_handler(&self, cx: &impl Actor) -> Result<(), Error>

Helper function to handle a message to an actor that just wants to forward it to the next owner.