pub struct MeshFailure {
pub actor_mesh_name: Option<String>,
pub rank: Option<usize>,
pub event: ActorSupervisionEvent,
}Expand description
Message about a supervision failure on a mesh of actors instead of a single actor.
Fields
actor_mesh_name: Option<String>Name of the mesh which the event originated from.
rank: Option<usize>Rank of the mesh from which the event originated. TODO: Point instead?
event: ActorSupervisionEventThe supervision event on an actor located at mesh + rank.
Implementations
Sourceimpl MeshFailure
impl MeshFailure